summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDuncan P. N. Exon Smith <dexonsmith@apple.com>2014-04-22 03:31:31 +0000
committerDuncan P. N. Exon Smith <dexonsmith@apple.com>2014-04-22 03:31:31 +0000
commitaa866b9ae733f58b99410739041086ca71e9c6dc (patch)
treeda8d2dbf926b50450685a61f1726178e75b229a7 /include
parentdf1956a475a0af71d6c3872658c962740bdbbba7 (diff)
downloadllvm-aa866b9ae733f58b99410739041086ca71e9c6dc.tar.gz
llvm-aa866b9ae733f58b99410739041086ca71e9c6dc.tar.bz2
llvm-aa866b9ae733f58b99410739041086ca71e9c6dc.tar.xz
blockfreq: Rename PackagedLoopData => LoopData
No functionality change. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@206855 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/llvm/Analysis/BlockFrequencyInfoImpl.h20
1 files changed, 8 insertions, 12 deletions
diff --git a/include/llvm/Analysis/BlockFrequencyInfoImpl.h b/include/llvm/Analysis/BlockFrequencyInfoImpl.h
index 5d129d1103..bea9f79aeb 100644
--- a/include/llvm/Analysis/BlockFrequencyInfoImpl.h
+++ b/include/llvm/Analysis/BlockFrequencyInfoImpl.h
@@ -937,15 +937,11 @@ public:
uint64_t Integer;
};
- /// \brief Data for a packaged loop.
+ /// \brief Data about a loop.
///
- /// Contains the data necessary to represent represent a loop as a node once
- /// it's packaged.
- ///
- /// PackagedLoopData inherits from BlockData to give the node the necessary
- /// stats. Further, it has a list of successors, list of members, and stores
- /// the backedge mass assigned to this loop.
- struct PackagedLoopData {
+ /// Contains the data necessary to represent represent a loop as a
+ /// pseudo-node once it's packaged.
+ struct LoopData {
typedef SmallVector<std::pair<BlockNode, BlockMass>, 4> ExitMap;
typedef SmallVector<BlockNode, 4> MemberList;
BlockNode Header; ///< Header.
@@ -955,7 +951,7 @@ public:
BlockMass Mass;
Float Scale;
- PackagedLoopData(const BlockNode &Header) : Header(Header) {}
+ LoopData(const BlockNode &Header) : Header(Header) {}
};
/// \brief Index of loop information.
@@ -1044,7 +1040,7 @@ public:
std::vector<WorkingData> Working;
/// \brief Indexed information about packaged loops.
- std::vector<PackagedLoopData> PackagedLoops;
+ std::vector<LoopData> PackagedLoops;
/// \brief Add all edges out of a packaged loop to the distribution.
///
@@ -1063,7 +1059,7 @@ public:
void addToDist(Distribution &Dist, const BlockNode &LoopHead,
const BlockNode &Pred, const BlockNode &Succ, uint64_t Weight);
- PackagedLoopData &getLoopPackage(const BlockNode &Head) {
+ LoopData &getLoopPackage(const BlockNode &Head) {
assert(Head.Index < Working.size());
size_t Index = Working[Head.Index].LoopIndex;
assert(Index < PackagedLoops.size());
@@ -1221,7 +1217,7 @@ template <> inline std::string getBlockName(const BasicBlock *BB) {
///
/// - Fetch and categorize the weight distribution for its successors.
/// If this is a packaged-subloop, the weight distribution is stored
/// in \a PackagedLoopData::Exits. Otherwise, fetch it from
/// BranchProbabilityInfo.
///
/// - Each successor is categorized as \a Weight::Local, a normal
@@ -1221,7 +1217,7 @@ template <> inline std::string getBlockName(const BasicBlock *BB) {
/// - Fetch and categorize the weight distribution for its successors.
/// If this is a packaged-subloop, the weight distribution is stored
-/// in \a PackagedLoopData::Exits. Otherwise, fetch it from
+/// in \a LoopData::Exits. Otherwise, fetch it from
/// BranchProbabilityInfo.
///